@@ -27,17 +27,21 @@
 #define __SEAHORSE_VALIDITY_H__
 
 #include <gtk/gtk.h>
+#include "cryptui.h"
+#include <gpgme.h>
 
 typedef enum {
-	SEAHORSE_VALIDITY_REVOKED = -2,
-	SEAHORSE_VALIDITY_DISABLED = -1,
-	SEAHORSE_VALIDITY_UNKNOWN = 1,
-	SEAHORSE_VALIDITY_NEVER = 2,
-	SEAHORSE_VALIDITY_MARGINAL = 3,
-	SEAHORSE_VALIDITY_FULL = 4,
-	SEAHORSE_VALIDITY_ULTIMATE = 5
+    SEAHORSE_VALIDITY_REVOKED =     CRYPTUI_VALIDITY_REVOKED,
+    SEAHORSE_VALIDITY_DISABLED =    CRYPTUI_VALIDITY_DISABLED,
+    SEAHORSE_VALIDITY_UNKNOWN =     CRYPTUI_VALIDITY_UNKNOWN,
+    SEAHORSE_VALIDITY_NEVER =       CRYPTUI_VALIDITY_NEVER,
+    SEAHORSE_VALIDITY_MARGINAL =    CRYPTUI_VALIDITY_MARGINAL,
+    SEAHORSE_VALIDITY_FULL =        CRYPTUI_VALIDITY_FULL,
+    SEAHORSE_VALIDITY_ULTIMATE =    CRYPTUI_VALIDITY_ULTIMATE
 } SeahorseValidity;
 
-const gchar*	seahorse_validity_get_string	(SeahorseValidity	validity);
+SeahorseValidity    seahorse_validity_from_gpgme    (gpgme_validity_t validity);
+
+const gchar*        seahorse_validity_get_string    (SeahorseValidity validity);
 
 #endif /* __SEAHORSE_VALIDITY_H__ */
